% DESCRIPTION [even,odd] = alamoutis_select(isamples, tb)
%   BPSK detector
% INPUT
%   samples  the data bearing signal
%   tb       duration of a data bit (in samples)
% OUTPUT
%   even     the indexes of the samples corresponding to
%            even data bits
%   odd      the indexes of the samples corresponding to
%            odd data bits
% 
% $Id: alamoutis_select.m,v 1.1 2003-05-12 16:39:50 sharky Exp $

function [even,odd] = alamoutis_select(isamples,tb)
% check number of samples
if rem(length(isamples),tb)
    error('the number of input samples is not a multiple of the bit duration!');
end

% check number of bits
nbits = length(isamples) / tb;
if rem(nbits,2)
    error('data must have an even number of bits!');
end

% make the odd and even masks
even = [];
odd = [];
for idx=0:(nbits/2-1)
    even = [ even (2*idx *tb + (1:tb)) ];
    odd = [ odd ( (2*idx+1) * tb + (1:tb)) ];
end

