% DESCRIPTION data = cdma_receive(recv,delay,par,alloc,h0,h1)
%   Decode the received signals into data
% INPUT
%   recv        signals received by the BTS's
%   delay       each user's transmission offset
%   par         simulation parameters
%   alloc       BTS and PN allocations
%   h0        channel multiplicative coefficients for antenna 0
%   h1        channel multiplicative coefficients for antenna 1
%
% OUTPUT
%   data        the decoded data for the users
%
% $Id: cdma_receive.m,v 1.3 2003-05-19 15:26:11 sharky Exp $

function data = cdma_receive(recv,delay,par,alloc,h0,h1)
% receiving
data = [];
for user = 1:par.nusers
  % keep only the frames corresponding to this user's transmission (strip out
  % the padding at the beginning and end)
  tmp = cdma_undelay(recv(alloc.bts(user),:),delay(user),par.maxdelay);
  
  % descrambling
  % tmp = cdma_despread(tmp,par.pn(alloc.bts(user)),par.tc/2);
  
  % despreading
  tmp = cdma_despread(tmp,par.pn(alloc.channel(user),:),par.tc);
  
  % do Alamouti processing
  if (par.alamouti)
      tmp = alamoutis_recep(tmp,par.tb,h0(user,:),h1(user,:));
  else
      tmp = conj(h0(user,:)) .* tmp;
  end
  
  % decode the data    
  data = [ data; bpsk_detect(tmp,conj(par.pulse)) ];    
end