% DESCRIPTION [trans,h0,h1] = cdma_transmit(par,alloc)
%   Calculate the signals transmitted by each user.
% INPUT
%   par         simulation parameters
%   alloc       BTS and PN allocations
%
% OUTPUT
%   trans       data, signals and delays for the users
%   h0        channel multiplicative coefficients for antenna 0
%   h1        channel multiplicative coefficients for antenna 1
%
% $Id: cdma_transmit.m,v 1.3 2003-05-19 14:24:17 sharky Exp $

function [trans,h0,h1] = cdma_transmit(par,alloc)

trans.data = 2 * (rand(par.nusers,par.data_len) > 0.5) -1;

% transmission
%trans.signal = zeros(par.nusers,par.data_len * par.tb + par.maxdelay);
%trans.delay = zeros(par.nusers,1);

h0 = zeros(par.nusers,par.data_len * par.tb);
h1 = zeros(par.nusers,par.data_len * par.tb);

for user = 1:par.nusers
  % we add a random-length padding at the beginning and thew complementary
  % padding at the end, so that the users do not transmit in a synchronous
  % fashion
  sigtmp = bpsk_mod(trans.data(user,:),par.pulse);
  
  h0(user,:) = flatten( ones(2*par.tb,1) * ( randn(1,par.data_len/2) + j*randn(1,par.data_len/2) )  )' / sqrt(2);
 
  % for Alamouti code
  if (par.alamouti)
    h1(user,:) = flatten( ones(2*par.tb,1) * ( randn(1,par.data_len/2) + j*randn(1,par.data_len/2) )  )' / sqrt(2);
    [ant0,ant1] = alamoutis_trans(sigtmp,par.tb);
    sigtmp = h0(user,:) .* ant0 + h1(user,:) .*ant1;
  else  
    sigtmp = h0(user,:) .* sigtmp;  
  end
  
  % channelization
  sigtmp = cdma_spread(sigtmp,par.pn(alloc.channel(user),:),par.tc);
  
  %trans_tmp = cdma_spread(sigtmp,pn(alloc.bts(user),:),par.tc / 2);
  
  [trans.signal(user,:),trans.delay(user)] = cdma_delay(sigtmp,par.maxdelay);  
end
